==> ejc-jlcost-impl-3.0.0-20240518.061854-48-sources.jar: com/ejianc/business/jlcost/finance/controller/InvoiceController.java <==
package com.ejianc.business.jlcost.finance.controller;

import java.io.Serializable;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.ejianc.business.jlcost.finance.bean.InvoiceDetailEntity;
import com.ejianc.business.jlcost.finance.service.IInvoiceDetailService;
import com.ejianc.business.jlcost.finance.vo.InvoiceDetailVO;
import com.ejianc.business.jlcost.finance.vo.InvoiceListVO;
import com.ejianc.foundation.orgcenter.vo.OrgVO;
import com.ejianc.foundation.support.vo.BillCodeParam;
import com.ejianc.foundation.support.api.IBillCodeApi;
import com.ejianc.foundation.support.api.IBillTypeApi;
import com.ejianc.framework.core.exception.BusinessException;
import com.ejianc.framework.core.util.ExcelExport;
import org.apache.commons.lang3.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import java.math.BigDecimal;
import java.util.*;
import java.util.stream.Collectors;

import com.alibaba.fastjson.JSONObject;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.*;
import org.apache.commons.collections.CollectionUtils;

import javax.servlet.http.HttpServletResponse;

import com.ejianc.foundation.orgcenter.api.IOrgApi;
import com.ejianc.framework.core.response.CommonResponse;
import org.springframework.beans.factory.annotation.Autowired;
import com.ejianc.framework.core.context.InvocationInfoProxy;
import com.ejianc.framework.core.kit.mapper.BeanMapper;
import com.ejianc.framework.core.kit.collection.ListUtil;
import com.ejianc.framework.auth.session.SessionManager;
import com.ejianc.framework.auth.session.UserContext;

import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.ejianc.framework.core.response.Parameter;
import com.ejianc.framework.core.response.QueryParam;

import com.ejianc.business.jlcost.finance.bean.InvoiceEntity;
import com.ejianc.business.jlcost.finance.service.IInvoiceService;
import com.ejianc.business.jlcost.finance.vo.InvoiceVO;

/**
 * 开票登记
 *
 * @author generator
 */
@Controller
@RequestMapping("invoice")
public class InvoiceController implements Serializable {
    private static final long serialVersionUID = 1L;

    private Logger logger = LoggerFactory.getLogger(this.getClass());

    @Autowired
    private IBillTypeApi billTypeApi;
    @Autowired
    private IBillCodeApi billCodeApi;
    @Autowired
    private IOrgApi iOrgApi;

    private static final String BILL_CODE = "INVOICE_CODE";//此处需要根据实际修改

    @Autowired
    private IInvoiceService service;

    @Autowired
    private IInvoiceDetailService detailService;

    @Autowired
    private SessionManager sessionManager;

    /**
     * @Description saveOrUpdate 新增或者修改
     */
    @RequestMapping(value = "/saveOrUpdate", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<InvoiceVO> saveOrUpdate(@RequestBody InvoiceVO saveOrUpdateVO) {
        InvoiceEntity entity = BeanMapper.map(saveOrUpdateVO, InvoiceEntity.class);
        if (entity.getId() == null || entity.getId() == 0) {
            BillCodeParam billCodeParam = BillCodeParam.build(BILL_CODE, InvocationInfoProxy.getTenantid(), saveOrUpdateVO);
            CommonResponse<String> billCode = billCodeApi.generateBillCode(billCodeParam);
            if (billCode.isSuccess()) {
                entity.setBillCode(billCode.getData());//此处需要根据实际修改 删除本行或者上一行
            } else {
                throw new BusinessException("网络异常， 编码生成失败， 请稍后再试");
            }
        }
        if (entity.getInvoiceMny() == null) {
            entity.setInvoiceMny(BigDecimal.ZERO);
        }
        if (entity.getInvoiceTax() == null) {
            entity.setInvoiceTax(BigDecimal.ZERO);
        }
        if (entity.getInvoiceTaxMny() == null) {
            entity.setInvoiceTaxMny(BigDecimal.ZERO);
        }
        service.saveOrUpdate(entity, false);
        InvoiceVO vo = BeanMapper.map(entity, InvoiceVO.class);
        return CommonResponse.success("保存或修改单据成功！", vo);
    }

    /**
     * @param id
     * @Description queryDetail 查询详情
     */
    @RequestMapping(value = "/queryDetail", method = RequestMethod.GET)
    @ResponseBody
    public CommonResponse<InvoiceVO> queryDetail(Long id) {
        InvoiceEntity entity = service.selectById(id);
        InvoiceVO vo = BeanMapper.map(entity, InvoiceVO.class);
        return CommonResponse.success("查询详情数据成功！", vo);
    }

    /**
     * @Description delete 批量删除单据
     * @Param [ids]
     */
    @RequestMapping(value = "/delete", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<String> delete(@RequestBody List<InvoiceVO> vos) {
        if (ListUtil.isNotEmpty(vos)) {
            for (InvoiceVO vo : vos) {
                // 参数是单据类型编码字符串 根据需求是否打开下面代码
                /* CommonResponse<String> resp = billTypeApi.checkQuote("billTypeCode", vo.getId());
                if(!resp.isSuccess()){
                    return CommonResponse.error("删除失败！"+resp.getMsg());
                }*/
            }
        }
        service.removeByIds(vos.stream().map(InvoiceVO::getId).collect(Collectors.toList()), true);
        return CommonResponse.success("删除成功！");
    }

    /**
     * @param param
     * @Description queryList 查询列表
     * @Return com.ejianc.framework.core.response.CommonResponse<java.lang.String>
     */
    @RequestMapping(value = "/queryList", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<IPage<InvoiceVO>> queryList(@RequestBody QueryParam param) {

        /** 模糊搜索配置字段示例 */
        List<String> fuzzyFields = param.getFuzzyFields();
        fuzzyFields.add("billCode");
        fuzzyFields.add("projectName");
        fuzzyFields.add("contractName");
        /** 租户隔离 */
        param.getParams().put("tenantId", new Parameter(QueryParam.EQ, InvocationInfoProxy.getTenantid()));

        param.getParams().put("orgId", new Parameter(QueryParam.IN, iOrgApi.findChildrenByParentId(InvocationInfoProxy.getOrgId()).getData().stream().map(OrgVO::getId).collect(Collectors.toList())));

        IPage<InvoiceEntity> page = service.queryPage(param, false);
        IPage<InvoiceVO> pageData = new Page<>(page.getCurrent(), page.getSize(), page.getTotal());
        pageData.setRecords(BeanMapper.mapList(page.getRecords(), InvoiceVO.class));

        return CommonResponse.success("查询列表数据成功！", pageData);
    }

    /**
     * 获取RPC数据
     * resp 返回值
     * isMustSuc 是否必须成功
     * errMsg 失败提示
     */
    private Object getRespData(CommonResponse<?> resp, boolean isMustSuc, String errMsg) {
        if (isMustSuc && !resp.isSuccess()) {
            throw new BusinessException(StringUtils.isNoneBlank(errMsg) ? errMsg : "调用Rpc服务失败");
        }
        return resp.getData();
    }


    /**
     * @param param
     * @Description 导出
     * @Return void
     */
    @RequestMapping(value = "/excelExport", method = RequestMethod.POST)
    @ResponseBody
    public void excelExport(@RequestBody QueryParam param, HttpServletResponse response) {
        /** 模糊搜索配置字段示例 */
        List<String> fuzzyFields = param.getFuzzyFields();
        param.getParams().put("tenant_id", new Parameter(QueryParam.EQ, InvocationInfoProxy.getTenantid()));
        param.setPageIndex(1);
        param.setPageSize(-1);
        /** 数据隔离 本下 没有组织orgId的删除下面代码 */
        param.getParams().put("orgId", new Parameter(QueryParam.IN, iOrgApi.findChildrenByParentId(InvocationInfoProxy.getOrgId()).getData().stream().map(OrgVO::getId).collect(Collectors.toList())));
        List<InvoiceEntity> list = service.queryList(param);
        List<InvoiceVO> resDatas = BeanMapper.mapList(list, InvoiceVO.class);
        for (InvoiceVO resData : resDatas) {
            switch (resData.getBillState()) {
                case 0:
                    resData.setBillStateName("自由态");
                    break;
                case 1:
                    resData.setBillStateName("已提交");
                    break;
                case 2:
                case 5:
                    resData.setBillStateName("审批中");
                    break;
                case 3:
                    resData.setBillStateName("审批通过");
                    break;
                case 4:
                    resData.setBillStateName("审批驳回");
                    break;
            }
        }
        //todo:字段翻译等等
        Map<String, Object> beans = new HashMap<>();
        beans.put("records", resDatas);
        ExcelExport.getInstance().export("Invoice-export.xlsx", beans, response);
    }

    /**
     * @param param
     * @Description 参照
     * @Return void
     */
    @RequestMapping(value = "/refInvoiceData", method = RequestMethod.GET)
    @ResponseBody
    public CommonResponse<IPage<InvoiceVO>> refInvoiceData(@RequestParam Integer pageNumber, @RequestParam Integer pageSize,
                                                           String condition,
                                                           String searchObject,
                                                           String searchText) {
        QueryParam param = new QueryParam();
        param.setPageSize(pageSize);
        param.setPageIndex(pageNumber);
        param.setSearchText(searchText);
        param.setSearchObject(searchObject);
        /** 租户隔离 */
        param.getParams().put("tenantId", new Parameter(QueryParam.EQ, InvocationInfoProxy.getTenantid()));
        if (StringUtils.isNotEmpty(condition)) {
            /** 处理condition */
            JSONObject _con = JSONObject.parseObject(condition);
        }

        IPage<InvoiceEntity> page = service.queryPage(param, false);
        IPage<InvoiceVO> pageData = new Page<>(page.getCurrent(), page.getSize(), page.getTotal());
        pageData.setRecords(BeanMapper.mapList(page.getRecords(), InvoiceVO.class));

        return CommonResponse.success("查询参照数据成功！", pageData);
    }

    @RequestMapping(value = "/getInvoiceCount", method = RequestMethod.GET)
    @ResponseBody
    public CommonResponse<BigDecimal> getInvoiceCount(Long contractId, Long rowId) {
        QueryWrapper<InvoiceEntity> wrapper = new QueryWrapper<InvoiceEntity>().eq("contract_id", contractId).eq("dr", 0);
        if (rowId != null) wrapper = wrapper.ne("id", rowId);
        List<InvoiceEntity> list = service.list(wrapper);
        BigDecimal count = new BigDecimal(0.00);
        for (InvoiceEntity invoiceEntity : list) {
            count = count.add(invoiceEntity.getInvoiceTaxMny() != null ? invoiceEntity.getInvoiceTaxMny() : BigDecimal.ZERO);
        }
        return CommonResponse.success(count);
    }

    @RequestMapping(value = "/getContractInvoice", method = RequestMethod.GET)
    @ResponseBody
    public CommonResponse<InvoiceListVO> getContractInvoice(Long contractId) {
        QueryParam param = new QueryParam();
        //根据合同ID查询
        param.getParams().put("contractId", new Parameter(QueryParam.EQ, contractId));
        //查询生效过滤
        List<Integer> billStates = new ArrayList<>();
        billStates.add(1);
        billStates.add(3);
        param.getParams().put("billState", new Parameter(QueryParam.IN, billStates));
        List<InvoiceEntity> list = service.queryList(param);
        if (list.size() == 0) {
            InvoiceListVO result = new InvoiceListVO();
            result.setCumulativeMny(BigDecimal.ZERO);
            result.setInvoiceDetailList(new ArrayList<>());
            return CommonResponse.success(result);
        }
        List<Long> ids = list.stream().map(invoice -> invoice.getId()).collect(Collectors.toList());
        List<InvoiceDetailEntity> InvoiceDetailList = detailService.list(new QueryWrapper<InvoiceDetailEntity>().in("invoice_id", ids));
        List<InvoiceDetailVO> resData = BeanMapper.mapList(InvoiceDetailList, InvoiceDetailVO.class);
        BigDecimal countMny = resData.size() > 0 ? resData.stream().map(e -> e.getDetailTaxMny()).reduce(BigDecimal::add).get() : BigDecimal.ZERO;
        InvoiceListVO result = new InvoiceListVO();
        result.setCumulativeMny(countMny);
        result.setInvoiceDetailList(resData);
        return CommonResponse.success(result);
    }
}

==> ejc-jlcost-impl-3.0.0-20240518.074735-50-sources.jar: com/ejianc/business/jlcost/finance/controller/InvoiceController.java <==
package com.ejianc.business.jlcost.finance.controller;

import java.io.Serializable;

import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.ejianc.business.jlcost.finance.bean.InvoiceDetailEntity;
import com.ejianc.business.jlcost.finance.service.IInvoiceDetailService;
import com.ejianc.business.jlcost.finance.vo.InvoiceDetailVO;
import com.ejianc.business.jlcost.finance.vo.InvoiceListVO;
import com.ejianc.foundation.orgcenter.vo.OrgVO;
import com.ejianc.foundation.support.vo.BillCodeParam;
import com.ejianc.foundation.support.api.IBillCodeApi;
import com.ejianc.foundation.support.api.IBillTypeApi;
import com.ejianc.framework.core.exception.BusinessException;
import com.ejianc.framework.core.response.BillStateEnum;
import com.ejianc.framework.core.util.ComputeUtil;
import com.ejianc.framework.core.util.ExcelExport;
import org.apache.commons.lang3.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import java.math.BigDecimal;
import java.util.*;
import java.util.stream.Collectors;

import com.alibaba.fastjson.JSONObject;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.*;
import org.apache.commons.collections.CollectionUtils;

import javax.servlet.http.HttpServletResponse;

import com.ejianc.foundation.orgcenter.api.IOrgApi;
import com.ejianc.framework.core.response.CommonResponse;
import org.springframework.beans.factory.annotation.Autowired;
import com.ejianc.framework.core.context.InvocationInfoProxy;
import com.ejianc.framework.core.kit.mapper.BeanMapper;
import com.ejianc.framework.core.kit.collection.ListUtil;
import com.ejianc.framework.auth.session.SessionManager;
import com.ejianc.framework.auth.session.UserContext;

import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.ejianc.framework.core.response.Parameter;
import com.ejianc.framework.core.response.QueryParam;

import com.ejianc.business.jlcost.finance.bean.InvoiceEntity;
import com.ejianc.business.jlcost.finance.service.IInvoiceService;
import com.ejianc.business.jlcost.finance.vo.InvoiceVO;

/**
 * 开票登记
 *
 * @author generator
 */
@Controller
@RequestMapping("invoice")
public class InvoiceController implements Serializable {
    private static final long serialVersionUID = 1L;

    private Logger logger = LoggerFactory.getLogger(this.getClass());

    @Autowired
    private IBillTypeApi billTypeApi;
    @Autowired
    private IBillCodeApi billCodeApi;
    @Autowired
    private IOrgApi iOrgApi;

    private static final String BILL_CODE = "INVOICE_CODE";//此处需要根据实际修改

    @Autowired
    private IInvoiceService service;

    @Autowired
    private IInvoiceDetailService detailService;

    @Autowired
    private SessionManager sessionManager;

    /**
     * @Description saveOrUpdate 新增或者修改
     */
    @RequestMapping(value = "/saveOrUpdate", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<InvoiceVO> saveOrUpdate(@RequestBody InvoiceVO saveOrUpdateVO) {
        InvoiceEntity entity = BeanMapper.map(saveOrUpdateVO, InvoiceEntity.class);
        if (entity.getId() == null || entity.getId() == 0) {
            BillCodeParam billCodeParam = BillCodeParam.build(BILL_CODE, InvocationInfoProxy.getTenantid(), saveOrUpdateVO);
            CommonResponse<String> billCode = billCodeApi.generateBillCode(billCodeParam);
            if (billCode.isSuccess()) {
                entity.setBillCode(billCode.getData());//此处需要根据实际修改 删除本行或者上一行
            } else {
                throw new BusinessException("网络异常， 编码生成失败， 请稍后再试");
            }
        }
        if (entity.getInvoiceMny() == null) {
            entity.setInvoiceMny(BigDecimal.ZERO);
        }
        if (entity.getInvoiceTax() == null) {
            entity.setInvoiceTax(BigDecimal.ZERO);
        }
        if (entity.getInvoiceTaxMny() == null) {
            entity.setInvoiceTaxMny(BigDecimal.ZERO);
        }
        service.saveOrUpdate(entity, false);
        InvoiceVO vo = BeanMapper.map(entity, InvoiceVO.class);
        return CommonResponse.success("保存或修改单据成功！", vo);
    }

    /**
     * @param id
     * @Description queryDetail 查询详情
     */
    @RequestMapping(value = "/queryDetail", method = RequestMethod.GET)
    @ResponseBody
    public CommonResponse<InvoiceVO> queryDetail(Long id) {
        InvoiceEntity entity = service.selectById(id);
        InvoiceVO vo = BeanMapper.map(entity, InvoiceVO.class);
        return CommonResponse.success("查询详情数据成功！", vo);
    }

    /**
     * @Description delete 批量删除单据
     * @Param [ids]
     */
    @RequestMapping(value = "/delete", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<String> delete(@RequestBody List<InvoiceVO> vos) {
        if (ListUtil.isNotEmpty(vos)) {
            for (InvoiceVO vo : vos) {
                // 参数是单据类型编码字符串 根据需求是否打开下面代码
                /* CommonResponse<String> resp = billTypeApi.checkQuote("billTypeCode", vo.getId());
                if(!resp.isSuccess()){
                    return CommonResponse.error("删除失败！"+resp.getMsg());
                }*/
            }
        }
        service.removeByIds(vos.stream().map(InvoiceVO::getId).collect(Collectors.toList()), true);
        return CommonResponse.success("删除成功！");
    }

    /**
     * @param param
     * @Description queryList 查询列表
     * @Return com.ejianc.framework.core.response.CommonResponse<java.lang.String>
     */
    @RequestMapping(value = "/queryList", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<IPage<InvoiceVO>> queryList(@RequestBody QueryParam param) {

        /** 模糊搜索配置字段示例 */
        List<String> fuzzyFields = param.getFuzzyFields();
        fuzzyFields.add("billCode");
        fuzzyFields.add("projectName");
        fuzzyFields.add("contractName");
        /** 租户隔离 */
        param.getParams().put("tenantId", new Parameter(QueryParam.EQ, InvocationInfoProxy.getTenantid()));

        param.getParams().put("orgId", new Parameter(QueryParam.IN, iOrgApi.findChildrenByParentId(InvocationInfoProxy.getOrgId()).getData().stream().map(OrgVO::getId).collect(Collectors.toList())));

        IPage<InvoiceEntity> page = service.queryPage(param, false);
        IPage<InvoiceVO> pageData = new Page<>(page.getCurrent(), page.getSize(), page.getTotal());
        pageData.setRecords(BeanMapper.mapList(page.getRecords(), InvoiceVO.class));

        return CommonResponse.success("查询列表数据成功！", pageData);
    }

    /**
     * 获取RPC数据
     * resp 返回值
     * isMustSuc 是否必须成功
     * errMsg 失败提示
     */
    private Object getRespData(CommonResponse<?> resp, boolean isMustSuc, String errMsg) {
        if (isMustSuc && !resp.isSuccess()) {
            throw new BusinessException(StringUtils.isNoneBlank(errMsg) ? errMsg : "调用Rpc服务失败");
        }
        return resp.getData();
    }


    /**
     * @param param
     * @Description 导出
     * @Return void
     */
    @RequestMapping(value = "/excelExport", method = RequestMethod.POST)
    @ResponseBody
    public void excelExport(@RequestBody QueryParam param, HttpServletResponse response) {
        /** 模糊搜索配置字段示例 */
        List<String> fuzzyFields = param.getFuzzyFields();
        param.getParams().put("tenant_id", new Parameter(QueryParam.EQ, InvocationInfoProxy.getTenantid()));
        param.setPageIndex(1);
        param.setPageSize(-1);
        /** 数据隔离 本下 没有组织orgId的删除下面代码 */
        param.getParams().put("orgId", new Parameter(QueryParam.IN, iOrgApi.findChildrenByParentId(InvocationInfoProxy.getOrgId()).getData().stream().map(OrgVO::getId).collect(Collectors.toList())));
        List<InvoiceEntity> list = service.queryList(param);
        List<InvoiceVO> resDatas = BeanMapper.mapList(list, InvoiceVO.class);
        for (InvoiceVO resData : resDatas) {
            switch (resData.getBillState()) {
                case 0:
                    resData.setBillStateName("自由态");
                    break;
                case 1:
                    resData.setBillStateName("已提交");
                    break;
                case 2:
                case 5:
                    resData.setBillStateName("审批中");
                    break;
                case 3:
                    resData.setBillStateName("审批通过");
                    break;
                case 4:
                    resData.setBillStateName("审批驳回");
                    break;
            }
        }
        //todo:字段翻译等等
        Map<String, Object> beans = new HashMap<>();
        beans.put("records", resDatas);
        ExcelExport.getInstance().export("Invoice-export.xlsx", beans, response);
    }

    /**
     * @param
     * @Description 参照
     * @Return void
     */
    @RequestMapping(value = "/refInvoiceData", method = RequestMethod.GET)
    @ResponseBody
    public CommonResponse<IPage<InvoiceVO>> refInvoiceData(@RequestParam Integer pageNumber, @RequestParam Integer pageSize,
                                                           String condition,
                                                           String searchObject,
                                                           String searchText) {
        QueryParam param = new QueryParam();
        param.setPageSize(pageSize);
        param.setPageIndex(pageNumber);
        param.setSearchText(searchText);
        param.setSearchObject(searchObject);
        /** 租户隔离 */
        param.getParams().put("tenantId", new Parameter(QueryParam.EQ, InvocationInfoProxy.getTenantid()));
        if (StringUtils.isNotEmpty(condition)) {
            /** 处理condition */
            JSONObject _con = JSONObject.parseObject(condition);
        }

        IPage<InvoiceEntity> page = service.queryPage(param, false);
        IPage<InvoiceVO> pageData = new Page<>(page.getCurrent(), page.getSize(), page.getTotal());
        pageData.setRecords(BeanMapper.mapList(page.getRecords(), InvoiceVO.class));

        return CommonResponse.success("查询参照数据成功！", pageData);
    }

    @RequestMapping(value = "/getInvoiceCount", method = RequestMethod.GET)
    @ResponseBody
    public CommonResponse<BigDecimal> getInvoiceCount(Long contractId, Long rowId) {
        BigDecimal sumInvoiceTaxMny = BigDecimal.ZERO;
        //开票金额
        LambdaQueryWrapper<InvoiceEntity> queryWrapper2 = new LambdaQueryWrapper<>();
        queryWrapper2.eq(InvoiceEntity::getContractId, contractId);
        queryWrapper2.in(InvoiceEntity::getBillState, BillStateEnum.PASSED_STATE.getBillStateCode(), BillStateEnum.COMMITED_STATE.getBillStateCode());
        queryWrapper2.orderByDesc(InvoiceEntity::getInvoiceDate);
        List<InvoiceEntity> list2 = service.list(queryWrapper2);
        if (CollectionUtils.isNotEmpty(list2)) {
            for (InvoiceEntity entity : list2) {
                sumInvoiceTaxMny = ComputeUtil.safeAdd(sumInvoiceTaxMny, entity.getInvoiceTaxMny());
            }
        }
        return CommonResponse.success(sumInvoiceTaxMny);
    }

    @RequestMapping(value = "/getContractInvoice", method = RequestMethod.GET)
    @ResponseBody
    public CommonResponse<InvoiceListVO> getContractInvoice(Long contractId) {
        QueryParam param = new QueryParam();
        //根据合同ID查询
        param.getParams().put("contractId", new Parameter(QueryParam.EQ, contractId));
        //查询生效过滤
        List<Integer> billStates = new ArrayList<>();
        billStates.add(1);
        billStates.add(3);
        param.getParams().put("billState", new Parameter(QueryParam.IN, billStates));
        List<InvoiceEntity> list = service.queryList(param);
        if (list.size() == 0) {
            InvoiceListVO result = new InvoiceListVO();
            result.setCumulativeMny(BigDecimal.ZERO);
            result.setInvoiceDetailList(new ArrayList<>());
            return CommonResponse.success(result);
        }
        List<Long> ids = list.stream().map(invoice -> invoice.getId()).collect(Collectors.toList());
        List<InvoiceDetailEntity> InvoiceDetailList = detailService.list(new QueryWrapper<InvoiceDetailEntity>().in("invoice_id", ids));
        List<InvoiceDetailVO> resData = BeanMapper.mapList(InvoiceDetailList, InvoiceDetailVO.class);
        BigDecimal countMny = resData.size() > 0 ? resData.stream().map(e -> e.getDetailTaxMny()).reduce(BigDecimal::add).get() : BigDecimal.ZERO;
        InvoiceListVO result = new InvoiceListVO();
        result.setCumulativeMny(countMny);
        result.setInvoiceDetailList(resData);
        return CommonResponse.success(result);
    }
}
